#!/bin/sh

# See below license for configuration!

VERSION="1.3"
WEBSITE="http://ludwig.spline.de/addnote/"
LICENSE="
 addnote.sh - add a line (esp. from clipboard) to a file really quickly
 Copyright (C) 2009  Ludwig Ortmann <ludwig@spline.de>

 This program is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program.  If not, see <http://www.gnu.org/licenses/>."

######################################
####### START OF CONFIGURATION #######

# this is where your notes end up:
FILENAME="${HOME}/newnotes.txt"

# set to "no" to keep, "yes" to remove newlines from input:
REMOVE_NEWLINES="yes"

# set to "yes" to append a newline after the input, no otherwise:
APPEND_NEWLINE="yes"

# set TOOLKIT to "qt" if you use kde, to "gtk" otherwise
TOOLKIT="gtk"

# window title and text:
DIALOG_TITLE="Add Note"
DIALOG_TEXT="Enter note:"

######## END OF CONFIGURATION ########
######################################

if test ${TOOLKIT} = "qt" && ! which kdialog >> /dev/null 2>&1 ; then
    echo "You need kdialog"
    exit 1
elif test ${TOOLKIT} = "gtk" && ! which zenity >> /dev/null 2>&1 ; then
    echo "You need zenity"
    exit 1
fi

# try to acquire content of x clipboard
if ! which xsel >> /dev/null 2>&1 ; then
    if ! which xclip >> /dev/null 2>&1; then
        echo "You need xsel or xclip"
    else
        CLIPBOARD=$(xclip -o)
    fi
else
    CLIPBOARD=$(xsel -o)
fi

# get note using kdialog or zenity
if [ ${TOOLKIT} = "qt" ]; then
    NOTE=$(kdialog \
        --title "${DIALOG_TITLE}" \
        --inputbox "${DIALOG_TEXT}" \
        "${CLIPBOARD}")
else
    NOTE=$(zenity --entry \
        --title="${DIALOG_TITLE}" \
        --text="${DIALOG_TEXT}" \
        --entry-text="${CLIPBOARD}")
fi
DOADD=$?

# if newlines should be removed, do so
if [ ${REMOVE_NEWLINES} = "yes" ] ; then
    NOTE=$(echo "${NOTE}" | awk '{printf("%s ", $0)}')
fi


# if the user did not hit cancel, append note to file
if [ ${DOADD} = 0 ]; then
    echo "${NOTE}" >> "${FILENAME}"
    # append newline if user wants this:
    if [ ${APPEND_NEWLINE} = "yes" ] ; then
        echo '' >> "${FILENAME}"
    fi
fi


exit 0
